@@ -19,6 +19,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
+#include <stdlib.h>
 
 #include "xchat.h"
 #include "cfgfiles.h"
@@ -38,7 +39,11 @@ ctcp_reply (session *sess, char *tbuf, char *nick, char *word[],
 {
 	int oldc = prefs.perc_color;
 
+	conf = strdup (conf);
+	/* process %C %B etc, on the config only (not the inbound text) */
+	check_special_chars (conf, TRUE);
 	auto_insert (tbuf, conf, word, word_eol, "", "", word_eol[5], "", "", nick);
+	free (conf);
 
 	/* must be disabled so the remote's text isn't interpreted with %xxx */
 	prefs.perc_color = 0;
