@@ -851,9 +851,10 @@ dcc_send (struct session *sess, char *tbuf, char *to, char *file)
 		char path[256];
 		char wild[256];
 
-		strcpy (wild, file_part (file));
-		path_part (file, path);
-		path[strlen (path) - 1] = 0;	/* remove trailing slash */
+		safe_strcpy (wild, file_part (file), sizeof (wild));
+		path_part (file, path, sizeof (path));
+		if (path[0] != '/' || path[1] != '\0')
+			path[strlen (path) - 1] = 0;	/* remove trailing slash */
 
 		dccsess = sess;
 		dccto = to;
