@@ -57,7 +57,7 @@ history_down (struct history *his)
 	{
 		if (his->pos == HISTORY_SIZE - 1)
 		{
-			his->pos++;
+			his->pos = 0;
 			return "";
 		}
 	} else
@@ -70,7 +70,7 @@ history_down (struct history *his)
 	}
 
 	next = 0;
-	if (his->pos != HISTORY_SIZE)
+	if (his->pos < HISTORY_SIZE - 1)
 		next = his->pos + 1;
 
 	if (his->lines[next])
