@@ -680,7 +680,7 @@ set_server_name (struct server *serv, char *name)
 	if (name[0] == 0)
 		name = serv->hostname;
 
-	strcpy (serv->servername, name);
+	safe_strcpy (serv->servername, name, sizeof (serv->servername));
 	while (list)
 	{
 		sess = (struct session *) list->data;
@@ -965,7 +965,7 @@ do_dns (struct session *sess, char *tbuf, char *nick, char *host)
 	if (po)
 		host = po + 1;
 	EMIT_SIGNAL (XP_TE_RESOLVINGUSER, sess, nick, host, NULL, NULL, 0);
-	sprintf (tbuf, "/exec %s %s", prefs.dnsprogram, host);
+	sprintf (tbuf, "/exec -d %s %s", prefs.dnsprogram, host);
 	handle_command (tbuf, sess, 0, 0);
 }
 
@@ -1395,7 +1395,7 @@ process_line (struct server *serv, char *buf)
 		return;
 	}
 
-	fe_add_rawlog (serv, buf, FALSE);
+	fe_add_rawlog (serv, buf, -1, FALSE);
 
 	fe_checkurl (buf);
 
