@@ -250,6 +250,7 @@ _xchat_new ()
 
 	self->state = PyThreadState_Get ();
 	self->name = NULL;
+	self->desc = NULL;
 	self->cmd_hooks = NULL;
 	self->sig_hooks = NULL;
 	self->timeout_hooks = NULL;
@@ -1161,6 +1162,7 @@ pys_pkill (struct session *sess, char *tbuf, char **word, char **word_eol)
 	if (!word[2] || word[2][0] == 0)
 		return FALSE;
 
+	obj = NULL;
 	cur = pys_list;
 	while (cur)
 	{
