@@ -100,7 +100,7 @@ server_connected (server * serv)
 	sprintf (outbuf, "%s/auth/xchat_auth", g_get_home_dir ());
 	if (access (outbuf, X_OK) == 0)
 	{
-		sprintf (outbuf, "/exec %s/auth/xchat_auth %s", g_get_home_dir (),
+		sprintf (outbuf, "/exec -d %s/auth/xchat_auth %s", g_get_home_dir (),
 					prefs.username);
 		handle_command (outbuf, serv->front_session, FALSE, FALSE);
 	}
@@ -282,6 +282,7 @@ ssl_do_connect (server * serv)
 		case X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY:
 		case X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE:
 		case X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT:
+		case X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN:
 			if (serv->accept_invalid_cert)
 			{
 				snprintf (buf, sizeof (buf), "* Verify E: %s.? (%d) -- Ignored",
@@ -1086,8 +1087,8 @@ connect_server (session * sess, char *hostname, int port, int no_login)
 
 	EMIT_SIGNAL (XP_TE_SERVERLOOKUP, sess, hostname, NULL, NULL, NULL, 0);
 
-	strcpy (serv->servername, hostname);
-	strcpy (serv->hostname, hostname);
+	safe_strcpy (serv->servername, hostname, sizeof (serv->servername));
+	strcpy (serv->hostname, serv->servername);
 
 	set_server_defaults (serv);
 	serv->connecting = TRUE;
