@@ -22,17 +22,22 @@
 #include <time.h>					  /* asctime() */
 #include <string.h>				  /* strncpy() */
 #include "ssl.h"					  /* struct cert_info */
-/* #include "/home/dap/r/openssl-0.9.4/ssl/ssl_locl.h" */
+#include "../../config.h"		  /* HAVE_SNPRINTF */
+
+#ifndef HAVE_SNPRINTF
+#define snprintf g_snprintf
+#endif
 
 /* globals */
-struct chiper_info chiper_info;		/* static buffer for _SSL_get_cipher_info() */
-char err_buf[256];			/* generic error buffer */
+static struct chiper_info chiper_info;		/* static buffer for _SSL_get_cipher_info() */
+static char err_buf[256];			/* generic error buffer */
 
 
 /* +++++ Internal functions +++++ */
 
 
-void *
+#if 0
+static void *
 mmalloc(size_t size)
 {
 	void *addr;
@@ -45,9 +50,10 @@ mmalloc(size_t size)
 	}
 	return (addr);
 }
+#endif
 
 
-void
+static void
 __SSL_fill_err_buf (char *funcname)
 {
 	int err;
@@ -60,7 +66,7 @@ __SSL_fill_err_buf (char *funcname)
 }
 
 
-void
+static void
 __SSL_critical_error (char *funcname)
 {
 	__SSL_fill_err_buf (funcname);
@@ -118,10 +124,11 @@ fprintf(stderr, "_SSL_EVP_encode :: encoded data is %d bytes\n", i);
 */
 
 
+#if 0
 #define	ALG	EVP_des_ede3_cbc()
 #define	MAXBLK	512
 /* FIXME */
-int
+static int
 _SSL_do_cipher(char *buf, int buf_len, char *key, int operation, char **pt)
 {
 	EVP_CIPHER_CTX ectx;
@@ -159,9 +166,11 @@ break;
 
 	return (i);
 }
+#endif
 
 
-char *
+#if 0
+static char *
 _SSL_do_cipher_base64(char *buf, int buf_len, char *key, int operation)
 {
 	char *pt;
@@ -193,12 +202,14 @@ fprintf(stderr, "_SSL_do_cipher_base64 :: EVP_DecodeBlock %d [%24s]\n", i, key);
 
 	return (pt2);
 }
+#endif
 
 
 /* +++++ Object functions +++++ */
 
 
-void *
+#if 0
+static void *
 _SSL_get_sess_obj(SSL *ssl, int type)
 {
 	void *obj = NULL;
@@ -217,9 +228,11 @@ _SSL_get_sess_obj(SSL *ssl, int type)
 	}
 	return (obj);
 }
+#endif
 
 
-char *
+#if 0
+static char *
 _SSL_get_obj_base64(void *s, int type)
 {
 	unsigned char *pt, *ppt;
@@ -265,9 +278,11 @@ _SSL_get_obj_base64(void *s, int type)
 
 	return (t);
 }
+#endif
 
 
-char *
+#if 0
+static char *
 _SSL_get_ctx_obj_base64(SSL_CTX *ctx, int type)
 {
 	void *obj;
@@ -285,9 +300,11 @@ _SSL_get_ctx_obj_base64(SSL_CTX *ctx, int type)
 
 	return (pt);
 }
+#endif
 
 
-int
+#if 0
+static int
 _SSL_verify_x509(X509 *x509)
 {
 	X509_STORE *cert_ctx = NULL;
@@ -332,6 +349,7 @@ _SSL_verify_x509(X509 *x509)
 
 	return (i);
 }
+#endif
 
 
 /* +++++ SSL functions +++++ */
@@ -341,7 +359,9 @@ SSL_CTX *
 _SSL_context_init (void (*info_cb_func), int server)
 {
 	SSL_CTX *ctx;
-
+#ifdef WIN32
+	int i, r;
+#endif
 
 	SSLeay_add_ssl_algorithms ();
 	SSL_load_error_strings ();
@@ -353,11 +373,22 @@ _SSL_context_init (void (*info_cb_func), int server)
 	/* used in SSL_connect(), SSL_accept() */
 	SSL_CTX_set_info_callback (ctx, info_cb_func);
 
+#ifdef WIN32
+	/* under win32, OpenSSL needs to be seeded with some randomness */
+	srand (time (0));
+	for (i = 0; i < 128; i++)
+	{
+		r = rand ();
+		RAND_seed ((unsigned char *)&r, sizeof (r));
+	}
+#endif
+
 	return(ctx);
 }
 
 
-void
+#if 0
+static void
 _SSL_add_random_keypair(SSL_CTX *ctx, int bits)
 {
 	RSA *rsa;
@@ -371,9 +402,11 @@ _SSL_add_random_keypair(SSL_CTX *ctx, int bits)
 	/* force use of this key for key exchange */
 	SSL_CTX_set_options(ctx, SSL_OP_EPHEMERAL_RSA);
 }
+#endif
 
 
-char *
+#if 0
+static char *
 _SSL_add_keypair (SSL_CTX *ctx, char *privkey, char *cert)
 {
 	if (SSL_CTX_use_PrivateKey_file (ctx, privkey, SSL_FILETYPE_PEM) <= 0)
@@ -396,10 +429,11 @@ _SSL_add_keypair (SSL_CTX *ctx, char *privkey, char *cert)
 
 	return (NULL);
 }
+#endif
 
 
 static struct tm tmtm;
-struct tm *
+static struct tm *
 ASN1_GENERALIZEDTIME_snprintf (ASN1_GENERALIZEDTIME * tm)
 {
 	char *v;
@@ -442,7 +476,7 @@ ASN1_GENERALIZEDTIME_snprintf (ASN1_GENERALIZEDTIME * tm)
 }
 
 
-struct tm *
+static struct tm *
 ASN1_UTCTIME_snprintf (ASN1_UTCTIME * tm)
 {
 	char *v;
@@ -485,7 +519,7 @@ ASN1_UTCTIME_snprintf (ASN1_UTCTIME * tm)
 }
 
 
-void
+static void
 ASN1_TIME_snprintf (char *buf, int buf_len, ASN1_TIME * tm)
 {
 	struct tm *tmtm;
@@ -514,7 +548,7 @@ ASN1_TIME_snprintf (char *buf, int buf_len, ASN1_TIME * tm)
 }
 
 
-void
+static void
 broke_oneline (char *oneline, char *parray[])
 {
 	char *pt, *ppt;
