@@ -19,8 +19,9 @@
 
 extern unsigned char tolowertab[];
 
+int my_poptParseArgvString(const char * s, int * argcPtr, char *** argvPtr);
 char *expand_homedir (char *file);
-void path_part (char *file, char *path);
+void path_part (char *file, char *path, int pathlen);
 int match (const char *mask, const char *string);
 char *file_part (char *file);
 int for_files (char *dirname, char *mask, void callback (char *file));
