@@ -36,7 +36,7 @@ void
 menu_about (GtkWidget * wid, gpointer sess)
 {
 	char buf[512];
-	const gchar *author[] = { "Peter Zelezny <zed@linux.com>", 0 };
+	const gchar *author[] = { "Peter Zelezny <zed@xchat.org>", 0 };
 
 	snprintf (buf, sizeof (buf),
 				 _("An IRC Client for UNIX.\n\n"
@@ -111,7 +111,7 @@ menu_about (GtkWidget * wid, gpointer sess)
 	gtk_container_add (GTK_CONTAINER (vbox), label);
 
 	snprintf (buf, sizeof (buf),
-				 _("(C) 1998-2001 Peter Zelezny <zed@linux.com>\n\n"
+				 _("(C) 1998-2001 Peter Zelezny <zed@xchat.org>\n\n"
 				 "An IRC Client for UNIX.\n\n"
 				 "This binary was compiled on "__DATE__"\n"
 				 "Using GTK %d.%d.%d X %d\n"
