@@ -354,12 +354,14 @@ fe_add_chan_list (struct server *serv, char *chan, char *users, char *topic)
  * The next several functions simply handle signals from widgets to update 
  * the list and state variables. 
  */
-static void
+static gboolean
 chanlist_editable_keypress (GtkWidget * widget, GdkEventKey * event,
 									 struct server *serv)
 {
 	if (event->keyval == GDK_Return)
 		chanlist_build_gui_list (serv);
+
+	return FALSE;
 }
 
 static void
