@@ -184,6 +184,18 @@ editlist_gui_save (GtkWidget * igad)
 				fe_buttons_update (sess);
 				list = list->next;
 			}
+		} else if (editlist_list == dlgbutton_list)
+		{
+			GSList *list = sess_list;
+			struct session *sess;
+			list_free (&dlgbutton_list);
+			list_loadconf (editlist_file, &dlgbutton_list, 0);
+			while (list)
+			{
+				sess = (struct session *) list->data;
+				fe_dlgbuttons_update (sess);
+				list = list->next;
+			}
 		} else if (editlist_list == ctcp_list)
 		{
 			list_free (&ctcp_list);
