@@ -48,7 +48,6 @@
 #undef GTK_FILE_SELECTION
 #undef GTK_PANED
 #undef GTK_TABLE
-#undef GTK_DRAWING_AREA
 #undef GTK_FONT_SELECTION_DIALOG
 #undef GTK_SCROLLED_WINDOW
 #undef GTK_TOGGLE_BUTTON
@@ -80,7 +79,6 @@
 #define GTK_FILE_SELECTION(n) ((GtkFileSelection *)n)
 #define GTK_PANED(n) ((GtkPaned *)n)
 #define GTK_TABLE(n) ((GtkTable *)n)
-#define GTK_DRAWING_AREA(n) ((GtkDrawingArea *)n)
 #define GTK_FONT_SELECTION_DIALOG(n) ((GtkFontSelectionDialog *)n)
 #define GTK_SCROLLED_WINDOW(n) ((GtkScrolledWindow *)n)
 #define GTK_TOGGLE_BUTTON(n) ((GtkToggleButton *)n)
