@@ -378,21 +378,20 @@ find_selected_nick (struct session *sess)
 	return user->nick;
 }
 
-static void
-ul_button_rel (GtkWidget * widget, GdkEventButton * even,
-					struct session *sess)
+static gboolean
+ul_button_rel (GtkWidget * widget, GdkEventButton * even, session *sess)
 {
 	char *nick;
 	int row, col;
 	char buf[67];
 
 	if (!even)
-		return;
+		return FALSE;
 	if (even->button == 3)
 	{
 		if (gtk_clist_get_selection_info
 			 (GTK_CLIST (widget), even->x, even->y, &row, &col) < 0)
-			return;
+			return FALSE;
 		gtk_clist_unselect_all (GTK_CLIST (widget));
 		gtk_clist_select_row (GTK_CLIST (widget), row, 0);
 		nick = find_selected_nick (sess);
@@ -400,7 +399,7 @@ ul_button_rel (GtkWidget * widget, GdkEventButton * even,
 		{
 			menu_nickmenu (sess, even, nick);
 		}
-		return;
+		return FALSE;
 	}
 	if (even->button == 2)
 	{
@@ -417,6 +416,8 @@ ul_button_rel (GtkWidget * widget, GdkEventButton * even,
 			}
 		}
 	}
+
+	return FALSE;
 }
 
 gboolean
@@ -1853,7 +1854,7 @@ create_window (struct session *sess)
 		else
 			gtk_widget_show (sess->gui->key_entry);
 
-		sess->gui->flag_k = add_flag_wid (_("Keyword"), tbox, _("K"), sess);
+		sess->gui->flag_k = add_flag_wid (_("Keyword"), tbox, "K", sess);
 
 		sess->gui->limit_entry = gtk_entry_new_with_max_length (10);
 		gtk_widget_set_usize (sess->gui->limit_entry, 30, -1);
