@@ -15,7 +15,7 @@ void userlist_hide (GtkWidget * igad, session *sess);
 int maingui_word_check (GtkWidget * xtext, char *word);
 void maingui_word_clicked (GtkWidget *xtext, char *word, GdkEventButton *even, session *sess);
 void link_cb (GtkWidget *win, session *sess);
-void focus_in (GtkWindow * win, GtkWidget * wid, session *sess);
+gboolean focus_in (GtkWindow * win, GdkEventFocus * event, session *sess);
 void maingui_configure (session *sess);
 void gui_create_toolbox (session *sess, GtkWidget *box);
 void gui_make_tab_window (session *sess, GtkWidget *win);
