@@ -18,33 +18,29 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include "../common/xchat.h"
+
 #include "fe-gtk.h"
+#include "../common/xchat.h"
+#include "../common/util.h"
+#include "../common/xchatc.h"
+#include "../common/cfgfiles.h"
 #include "gtkutil.h"
 #include "xtext.h"
-#include "../common/util.h"
+#include "wins.h"
 
 
-extern int cfg_get_int_with_result (char *cfg, char *var, int *result);
-extern int cfg_get_int (char *cfg, char *var);
-extern void cfg_put_int (int fh, int val, char *var);
-extern char *get_xdir (void);
-
-extern struct xchatprefs prefs;
-extern GSList *sess_list;
-extern GtkStyle *channelwin_style;
-
 GdkColor colors[] = {
-	{0, 0x0000, 0x0000, 0x0000}, /* 0  black */
-	{0, 0xcf3c, 0xcf3c, 0xcf3c}, /* 1  white */
+	{0, 0xcf3c, 0xcf3c, 0xcf3c}, /* 0  white */
+	{0, 0x0000, 0x0000, 0x0000}, /* 1  black */
 	{0, 0x0000, 0x0000, 0xcccc}, /* 2  blue */
 	{0, 0x0000, 0xcccc, 0x0000}, /* 3  green */
-	{0, 0xcccc, 0x0000, 0x0000}, /* 4  red */
-	{0, 0xbbbb, 0xbbbb, 0x0000}, /* 5  yellow/brown */
+	{0, 0xdddd, 0x0000, 0x0000}, /* 4  red */
+	{0, 0xaaaa, 0x0000, 0x0000}, /* 5  light red */
 	{0, 0xbbbb, 0x0000, 0xbbbb}, /* 6  purple */
 	{0, 0xffff, 0xaaaa, 0x0000}, /* 7  orange */
 	{0, 0xeeee, 0xdddd, 0x2222}, /* 8  yellow */
@@ -52,7 +48,7 @@ GdkColor colors[] = {
 	{0, 0x0000, 0xcccc, 0xcccc}, /* 10 aqua */
 	{0, 0x3333, 0xdddd, 0xeeee}, /* 11 light aqua */
 	{0, 0x0000, 0x0000, 0xffff}, /* 12 blue */
-	{0, 0x9999, 0x2222, 0xeeee}, /* 13 light purple */
+	{0, 0xeeee, 0x2222, 0xeeee}, /* 13 light purple */
 	{0, 0x7777, 0x7777, 0x7777}, /* 14 grey */
 	{0, 0x9999, 0x9999, 0x9999}, /* 15 light grey */
 	{0, 0xbe00, 0xbe00, 0xbe00}, /* 16 marktext Back (white) */
@@ -69,10 +65,12 @@ void
 palette_alloc (GtkWidget * widget)
 {
 	int i;
+	static int done_alloc = FALSE;
 
-	if (!colors[0].pixel)		  /* don't do it again */
+	if (!done_alloc)		  /* don't do it again */
 	{
-		for (i = 0; i < 20; i++)
+		done_alloc = TRUE;
+		for (i = 19; i >= 0; i--)
 		{
 			colors[i].pixel = (gulong) ((colors[i].red & 0xff00) * 256 +
 												 (colors[i].green & 0xff00) +
@@ -93,7 +91,7 @@ palette_load (void)
 	unsigned long red, green, blue;
 
    snprintf (prefname, sizeof (prefname), "%s/palette.conf", get_xdir ());
-   fh = open (prefname, O_RDONLY);
+   fh = open (prefname, O_RDONLY | OFLAGS);
 	if (fh != -1)
 	{
 		fstat (fh, &st);
@@ -136,7 +134,7 @@ palette_save (void)
 	char prefname[256];
 
    snprintf (prefname, sizeof (prefname), "%s/palette.conf", get_xdir ());
-   fh = open (prefname, O_TRUNC | O_WRONLY | O_CREAT, 0600);
+   fh = open (prefname, O_TRUNC | O_WRONLY | O_CREAT | OFLAGS, 0600);
 	if (fh != -1)
 	{
 		for (i = 0; i < 20; i++)
@@ -154,7 +152,7 @@ palette_save (void)
 	}
 }
 
-static int
+static void
 palette_edit_destroy_callback ()
 {
 	GSList *list;
@@ -164,7 +162,7 @@ palette_edit_destroy_callback ()
 	while (list)
 	{
 		sess = list->data;
-		if (!sess->is_shell)
+		if (sess->type != SESS_SHELL)
 		{
 			gtk_xtext_set_palette (GTK_XTEXT (sess->gui->textgad), colors);
 			gtk_xtext_refresh (GTK_XTEXT (sess->gui->textgad), 0);
@@ -173,7 +171,6 @@ palette_edit_destroy_callback ()
 	}
 
 	palwin = 0;
-	return 0;
 }
 
 static void
@@ -225,7 +222,7 @@ palette_editcolor (GtkWidget * button, GdkColor * color)
 	col[1] = color->green / 65535.0;
 	col[2] = color->blue / 65535.0;
 
-	dialog = gtk_color_selection_dialog_new ("Select color");
+	dialog = gtk_color_selection_dialog_new (_("Select color"));
 	gtk_widget_hide (GTK_COLOR_SELECTION_DIALOG (dialog)->help_button);
 	gtk_signal_connect (GTK_OBJECT
 							  (((GtkColorSelectionDialog *) dialog)->ok_button),
@@ -253,17 +250,13 @@ palette_edit ()
 
 	if (palwin)
 	{
-		gdk_window_show (palwin->window);
+		wins_bring_tofront (palwin);
 		return;
 	}
-	palwin = gtkutil_window_new ("X-Chat: Palette", "Palette",
-										  0, 0, palette_edit_destroy_callback, 0,
-										  FALSE);
 
-	mainbox = gtk_vbox_new (0, 5);
-	gtk_container_set_border_width (GTK_CONTAINER (mainbox), 6);
-	gtk_container_add (GTK_CONTAINER (palwin), mainbox);
-	gtk_widget_show (mainbox);
+	palwin = maingui_window ("palette", _("X-Chat: Palette"), TRUE, FALSE,
+									 palette_edit_destroy_callback, NULL, 0, 0, NULL);
+	mainbox = wins_get_vbox (palwin);
 
 	hbox = gtk_hbox_new (0, 2);
 	gtk_container_add (GTK_CONTAINER (mainbox), hbox);
@@ -280,19 +273,19 @@ palette_edit ()
 		switch (i)
 		{
 		case 18:
-			strcpy (tbuf, "Foreground");
+			strcpy (tbuf, _("Foreground"));
 			break;
 		case 19:
-			strcpy (tbuf, "Background");
+			strcpy (tbuf, _("Background"));
 			break;
 		case 16:
-			strcpy (tbuf, "Mark Background");
+			strcpy (tbuf, _("Mark Background"));
 			break;
 		case 17:
-			strcpy (tbuf, "Mark Foreground");
+			strcpy (tbuf, _("Mark Foreground"));
 			break;
 		default:
-			snprintf (tbuf, sizeof tbuf, "Color %d", i);
+			snprintf (tbuf, sizeof tbuf, _("Color %d"), i);
 		}
 		wid = gtk_button_new_with_label (tbuf);
 		gtk_object_set_user_data (GTK_OBJECT (wid), &colors[i]);
@@ -330,7 +323,7 @@ palette_edit ()
 	gtk_widget_set_usize (bbbox, 100, 0);
 	gtk_widget_show (bbbox);
 
-	gtkutil_button (palwin, GNOME_STOCK_BUTTON_OK, "OK",
+	gtkutil_button (palwin, GNOME_STOCK_BUTTON_OK, _("OK"),
 						 gtkutil_destroy, palwin, bbbox);
 
 	gtk_widget_show (palwin);
