@@ -1,4 +1,5 @@
 extern GdkPixmap *pix_globe;
+extern GdkPixmap *pix_admin;
 extern GdkPixmap *pix_op;
 extern GdkPixmap *pix_hop;
 extern GdkPixmap *pix_voice;
@@ -7,6 +8,7 @@ extern GdkPixmap *pix_xchat_mini;
 extern GdkPixmap *pix_xchat;
 
 extern GdkBitmap *mask_globe;
+extern GdkBitmap *mask_admin;
 extern GdkBitmap *mask_op;
 extern GdkBitmap *mask_hop;
 extern GdkBitmap *mask_voice;
@@ -14,7 +16,6 @@ extern GdkBitmap *mask_server;
 extern GdkBitmap *mask_xchat_mini;
 extern GdkBitmap *mask_xchat;
 
-extern GdkPixmap *pixmap_load_from_file_with_msg (char *file);
 extern GdkPixmap *pixmap_load_from_file (char *file);
 extern void pixmaps_init (void);
 
