@@ -65,7 +65,7 @@ rawlog_save (struct server *serv, void *unused, char *file)
 	}
 }
 
-static int
+static gboolean
 rawlog_keypress (GtkWidget * wid, GdkEventKey * event, struct server *serv)
 {
 	if (event->keyval == GDK_s && event->state & GDK_MOD1_MASK)
@@ -117,7 +117,7 @@ open_rawlog (struct server *serv)
 }
 
 void
-fe_add_rawlog (struct server *serv, char *text, int outbound)
+fe_add_rawlog (struct server *serv, char *text, int len, int outbound)
 {
 	int scroll = FALSE;
 	GtkAdjustment *adj;
@@ -136,7 +136,7 @@ fe_add_rawlog (struct server *serv, char *text, int outbound)
 			gtk_text_insert (GTK_TEXT (serv->gui->rawlog_textlist), 0,
 								  &colors[4], 0, ">> ", 3);
 		gtk_text_insert (GTK_TEXT (serv->gui->rawlog_textlist), 0, 0, 0, text,
-							  -1);
+							  len);
 		if (!outbound)
 			gtk_text_insert (GTK_TEXT (serv->gui->rawlog_textlist), 0, 0, 0,
 								  "\n", 1);
