@@ -34,7 +34,7 @@ static const struct defaultserv dserv[] =
 
 	{"", "SUB", "IRCNet", 0},
 	{"", "us.ircnet.org", "IRCNet USA", 6667},
-	{"", "eu.ircnet.org", "IRCNet Europe", 6667},
+	{"", "random.ircd.de", "IRCNet Europe", 6667},
 	{"", "irc.ircd.it", "IRCNet Italy", 6667},
 	{"", "au.ircnet.org", "IRCNet Australia", 6667},
 	{"", "irc.stealth.net", "irc.stealth.net", 6660},
@@ -127,7 +127,7 @@ static const struct defaultserv dserv[] =
 	{"", "ENDSUB", "", 0},
 
 	{"", "SUB", "KewlNet", 0},
-	{"", "irc.kewl.org", "irc.kewl.org", 6667},
+	{"", "random.irc.kewl.org", "random.irc.kewl.org", 6667},
 	{"", "la.defense.fr.eu.kewl.org", "la.defense.fr.eu.kewl.org", 6667},
 	{"", "nanterre.fr.eu.kewl.org", "nanterre.fr.eu.kewl.org", 6667},
 	{"", "ENDSUB", "", 0},
@@ -325,16 +325,8 @@ static const struct defaultserv dserv[] =
 	{"", "ENDSUB", "", 0},
 
 	{"", "SUB", "AzzurraNet", 0},
-	{"", "irc.bitchx.it", "irc.bitchx.it", 6667},
-	{"", "irc.jnet.it", "irc.jnet.it", 6667},
-	{"", "irc.net36.com", "irc.net36.com", 6667},
-	{"", "irc.noflyzone.net", "irc.noflyzone.net", 6667},
-	{"", "irc.swappoint.com", "irc.swappoint.com", 6667},
-	{"", "irc.azzurra.com", "irc.azzurra.com", 6667},
-	{"", "irc.leonet.it", "irc.leonet.it", 6667},
-	{"", "irc.libero.it", "irc.libero.it", 6667},
-	{"", "irc.estranet.it", "irc.estranet.it", 6667},  
-	{"", "irc.filmaker.it", "irc.filmaker.st", 6667},
+	{"", "irc.azzurra.org", "irc.azzurra.org", 6667},
+	{"", "crypto.azzurra.org", "crypto.azzurra.org", 9999},
 	{"", "ENDSUB", "", 0},
 
 	{"", "SUB", "NixHelpNet", 0},
@@ -480,6 +472,22 @@ static const struct defaultserv dserv[] =
 	{"", "irc.freeworld.nu", "Reston, VA", 6667},
 	{"", "ENDSUB", "", 0},
 
+	{"", "SUB", "hashmark", 0},
+	{"#hashmark", "irc.hashmark.net", "irc.hashmark.net", 6667},
+	{"", "ENDSUB", "", 0},
+
+	{"", "SUB", "German-Elite-Network", 0},
+	{"", "dominion.german-elite.net", "dOminiOn.german-elite.net", 6667},
+	{"", "komatu.german-elite.net", "komatu.german-elite.net", 6667},
+	{"", "liberty.german-elite.net", "liberty.german-elite.net", 6667},
+	{"", "ENDSUB", "", 0},
+
+	{"", "SUB", "Evolnet", 0},
+	{"", "irc.evolnet.org", "irc.evolnet.org", 6667},
+	{"", "bean.evolnet.org", "bean.evolnet.org", 6667},
+	{"", "blender.evolnet.org", "blender.evolnet.org", 6667},
+	{"", "ENDSUB", "", 0},
+
 /*	{"", "SUB", "", 0},
 	{"", "", "", 6667},
 	{"", "ENDSUB", "", 0},*/
