@@ -137,7 +137,7 @@ settings_create_optmenu (GtkWidget *table, char *label, char **text,
 	i = 0;
 	while (text[i])
 	{
-		menu_quick_item_with_callback (callback, text[i], menu, GINT_TO_POINTER (i));
+		menu_quick_item_with_callback (callback, _(text[i]), menu, GINT_TO_POINTER (i));
 		i++;
 	}
 
