@@ -38,15 +38,6 @@
 #include "palette.h"
 #include "textgui.h"
 
-struct text_event
-{
-	char *name;
-	char **help;
-	char *def;
-	int num_args;
-	char *sound;
-};
-
 extern struct text_event te[];
 extern char **pntevts_text;
 extern char **pntevts;
@@ -150,7 +141,7 @@ pevent_dialog_update_sound (GtkWidget * wid, GtkWidget * clist)
 	gtk_clist_set_text (GTK_CLIST (clist), row, 2,
 							  gtk_entry_get_text (GTK_ENTRY (wid)));
 
-	sig = (int) gtk_clist_get_row_data (GTK_CLIST (clist), row);
+	sig = GPOINTER_TO_INT (gtk_clist_get_row_data (GTK_CLIST (clist), row));
 
 	if (te[sig].sound)
 		free (te[sig].sound);
@@ -258,7 +249,7 @@ pevent_dialog_select (GtkWidget * clist, gint row, gint column,
 		gtk_entry_set_text (GTK_ENTRY (pevent_dialog_entry), cmd);
 		gtk_clist_get_text (GTK_CLIST (clist), row, 2, &snd);
 		gtk_entry_set_text (GTK_ENTRY (pevent_dialog_sound_entry), snd);
-		sig = (int) gtk_clist_get_row_data (GTK_CLIST (clist), row);
+		sig = GPOINTER_TO_INT (gtk_clist_get_row_data (GTK_CLIST (clist), row));
 		pevent_dialog_hfill (pevent_dialog_hlist, sig);
 	} else
 	{
@@ -285,7 +276,7 @@ pevent_dialog_fill (GtkWidget * list)
 		else
 			nnew[2] = "";
 		row = gtk_clist_append (GTK_CLIST (list), nnew);
-		gtk_clist_set_row_data (GTK_CLIST (list), row, (void *) i);
+		gtk_clist_set_row_data (GTK_CLIST (list), row, GINT_TO_POINTER (i));
 	}
 }
 
@@ -419,7 +410,7 @@ pevent_dialog_show ()
 	pevent_dialog_twid = gtk_xtext_new (0, 0);
 
 	gtk_xtext_set_palette (GTK_XTEXT (pevent_dialog_twid), colors);
-	gtk_xtext_set_font (GTK_XTEXT (pevent_dialog_twid), font_normal, 0);
+	gtk_xtext_set_font (GTK_XTEXT (pevent_dialog_twid), font_normal);
 	gtk_xtext_set_background (GTK_XTEXT (pevent_dialog_twid),
 									  channelwin_pix, prefs.transparent, prefs.tint);
 
