@@ -18,7 +18,7 @@
  *
  * xtext, the text widget used by X-Chat.
  *
- * By Peter Zelezny <zed@linux.com>.
+ * By Peter Zelezny <zed@xchat.org>.
  * Some functions used from Zvt and Eterm (transparency stuff).
  *
  */
@@ -1458,10 +1458,10 @@ gtk_xtext_selection_get (GtkWidget * widget,
 	*pos = 0;
 
 	if (xtext->color_paste)
-		stripped = gtk_xtext_conv_color (txt, strlen (txt), NULL, NULL,
+		stripped = gtk_xtext_conv_color (txt, strlen (txt), NULL, &len,
 													xtext->fonttype);
 	else
-		stripped = gtk_xtext_strip_color (txt, strlen (txt), NULL, NULL,
+		stripped = gtk_xtext_strip_color (txt, strlen (txt), NULL, &len,
 													 xtext->fonttype, NULL);
 	free (txt);
 
@@ -1486,7 +1486,7 @@ gtk_xtext_selection_get (GtkWidget * widget,
 		g_free (loc);
 #else
 		gtk_selection_data_set (selection_data_ptr, GDK_SELECTION_TYPE_STRING,
-										8, stripped, strlen (stripped));
+										8, stripped, len);
 #endif
 	}
 
