@@ -161,12 +161,11 @@ void gtk_xtext_append (GtkXText * xtext, unsigned char *text, int len);
 void gtk_xtext_append_indent (GtkXText * xtext,
 										unsigned char *left_text, int left_len,
 										unsigned char *right_text, int right_len);
-void gtk_xtext_set_font (GtkXText * xtext, GdkFont * font, char *name);
+void gtk_xtext_set_font (GtkXText * xtext, GdkFont * font);
 void gtk_xtext_set_background (GtkXText * xtext, GdkPixmap * pixmap,
 										 int trans, int shaded);
 void gtk_xtext_set_palette (GtkXText * xtext, GdkColor palette[]);
 void gtk_xtext_clear (GtkXText * xtext);
-gchar *gtk_xtext_get_chars (GtkXText * xtext);
 void gtk_xtext_refresh (GtkXText * xtext, int do_trans);
 void gtk_xtext_thaw (GtkXText * xtext);
 void gtk_xtext_freeze (GtkXText * xtext);
