@@ -29,6 +29,10 @@ typedef struct gslist GSList;
 #define g_new(a,b) malloc(sizeof(a)*b)
 #define g_new0(a,b) calloc(b,sizeof(a))
 
+/* don't compile with --disable-glib on 64bit systems */
+#define GINT_TO_POINTER(i) ((void *) (i))
+#define GPOINTER_TO_INT(p) ((int) (p))
+
 #ifndef TRUE
 #define TRUE 1
 #endif
